/* window.c
 *
 * Copyright 2020 Zander Brown
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "config.h"
#include "window.h"


#include <glib/gi18n-lib.h>


struct _DsnTypography {
  GtkApplicationWindow parent_instance;
};


G_DEFINE_TYPE (DsnTypography, dsn_typography, GTK_TYPE_APPLICATION_WINDOW)


static void
dsn_typography_class_init (DsnTypographyClass *klass)
{
  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);

  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/design/Typography/window.ui");
}


static void
copy_activated (GSimpleAction *action,
                GVariant      *parameter,
                gpointer       data)
{
  GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (data));
  GdkClipboard *clipboard = gdk_display_get_clipboard (display);

  gdk_clipboard_set_text (clipboard, g_variant_get_string (parameter, NULL));
}


static void
guidelines_activated (GSimpleAction *action,
                      GVariant      *parameter,
                      gpointer       data)
{
  guint32 stamp = GDK_CURRENT_TIME;
  gtk_show_uri (data,
                "https://developer.gnome.org/hig/guidelines/typography.html",
                stamp);
}


static void
about_activated (GSimpleAction *action,
                 GVariant      *parameter,
                 gpointer       data)
{
  const char *authors[] = { "Zander Brown <zbrown@gnome.org>", NULL };
  const char *artists[] = { "Tobias Bernard", NULL };
  g_autofree char *copyright = NULL;

  copyright = g_strdup_printf (_("Copyright © %s Zander Brown"),
                               "2020");

  gtk_show_about_dialog (GTK_WINDOW (data),
                         "authors", authors,
                         "artists", artists,
                         // Translators: Credit yourself here
                         "translator-credits", _("translator-credits"),
                         "copyright", copyright,
                         "license-type", GTK_LICENSE_GPL_3_0,
                         "logo-icon-name", "org.gnome.design.Typography",
                         "program-name", _("Typography"),
                         "version", PACKAGE_VERSION,
                         NULL);
}


static const GActionEntry entries[] = {
  { "copy", copy_activated, "s", NULL, NULL },
  { "guidelines", guidelines_activated, NULL, NULL, NULL },
  { "about", about_activated, NULL, NULL, NULL },
};


static void
dsn_typography_init (DsnTypography *self)
{
  gtk_widget_init_template (GTK_WIDGET (self));

  g_action_map_add_action_entries (G_ACTION_MAP (self),
                                   entries,
                                   G_N_ELEMENTS (entries),
                                   self);

}

